==> haskell-pattern-arrows-0.0.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
key: pattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
author: Phil Freeman <paf31@cantab.net>
exposed: True
indefinite: False
exposed-modules:
    Control.PatternArrows
abi: 6a125303ef269fd5b563e072fb5d29bb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pattern-arrows-0.0.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
key: pattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
author: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
abi: 76acea8cda09866508cdbf6476756151
exposed: True
exposed-modules:
    Control.PatternArrows
import-dirs: /usr/lib/ghc-8.4.2/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
depends:
    base-4.11.1.0 mtl-2.2.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
